@@ -35,10 +35,3 @@ my_message <- function(..., level = 1){
 
 }
 
-# check loaded package
-check_package_loaded <- function(package_name){
-  if (!requireNamespace(package_name, quietly = TRUE)) {
-    stop(paste0(package_name, " needed for this function to work. Please install it"),
-         call. = FALSE)
-  }
-}
